@@ -793,6 +793,7 @@ void Graph::removeGraph()
   graph_list::iterator target = graphAt(QPoint(0, origin_y));
   if (target != end()) {
     glist.erase(target);
+    changed(true);
   }
   layout();
   update();
@@ -858,10 +859,6 @@ void Graph::mousePressEvent(QMouseEvent *e)
   }
 }
 
-void Graph::mouseDoubleClickEvent(QMouseEvent *)
-{
-}
-
 /**
  * Qt mouse-event
  *
